@@ -10,10 +10,10 @@ require POSIX;
 
 use vars qw(@ISA $VERSION);
 
-$VERSION = 1.00; # keep same as in Tty.pm
+$VERSION = '1.08_01'; # keep same as in Tty.pm
 
 @ISA = qw(IO::Handle);
-eval { require IO::Stty };
+eval { local $^W = 0; undef local $SIG{__DIE__}; require IO::Stty };
 push @ISA, "IO::Stty" if (not $@);  # if IO::Stty is installed
 
 sub new {
@@ -68,7 +68,7 @@ sub slave {
     return ${*$master}{'io_pty_slave'};
   }
 
-  my $tty = $master->ttyname();
+  my $tty = ${*$master}{'io_pty_ttyname'};
 
   my $slave = new IO::Tty;
 
@@ -115,13 +115,15 @@ sub make_slave_controlling_terminal {
   }
 
   # Acquire a controlling terminal if this doesn't happen automatically
-  if (defined TIOCSCTTY) {
-    if (not defined ioctl( ${*$self}{'io_pty_slave'}, TIOCSCTTY, 0 )) {
-      warn "warning: TIOCSCTTY failed, slave might not be set as controlling terminal: $!" if $^W;
-    }
-  } elsif (defined TCSETCTTY) {
-    if (not defined ioctl( ${*$self}{'io_pty_slave'}, TCSETCTTY, 0 )) {
-      warn "warning: TCSETCTTY failed, slave might not be set as controlling terminal: $!" if $^W;
+  if (not open(\*DEVTTY, "/dev/tty")) {
+    if (defined TIOCSCTTY) {
+      if (not defined ioctl( ${*$self}{'io_pty_slave'}, TIOCSCTTY, 0 )) {
+        warn "warning: TIOCSCTTY failed, slave might not be set as controlling terminal: $!" if $^W;
+      }
+    } elsif (defined TCSETCTTY) {
+      if (not defined ioctl( ${*$self}{'io_pty_slave'}, TCSETCTTY, 0 )) {
+        warn "warning: TCSETCTTY failed, slave might not be set as controlling terminal: $!" if $^W;
+      }
     }
   }
 
@@ -148,7 +150,7 @@ IO::Pty - Pseudo TTY object class
 
 =head1 VERSION
 
-1.00
+1.08
 
 =head1 SYNOPSIS
 
